Clean laboratory variables by removing '<' and '>' characters and converting to numeric Cleans all columns starting with "lab_" (per Acutelines standard)
Source:R/postprocess.r
clean_lab.RdClean laboratory variables by removing '<' and '>' characters and converting to numeric Cleans all columns starting with "lab_" (per Acutelines standard)
See also
Other postprocessing:
normalize_decimal_format()