Normalize decimal format in a data frame Interprets both "." and "," as decimal indicators
Source:R/postprocess.r
normalize_decimal_format.RdNormalize decimal format in a data frame Interprets both "." and "," as decimal indicators
See also
Other postprocessing:
clean_lab()